__version__ = "2.0.0"


from habluetooth import BluetoothServiceInfo, BluetoothServiceInfoBleak

SOURCE_LOCAL = "local"

__all__ = [
    "BluetoothServiceInfo",
    "BluetoothServiceInfoBleak",
    "SOURCE_LOCAL",
]
